#!/bin/bash
#

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
cmakedir=${PRODUCTS}/cmake/v2_8_4/${flvr}
sourcedir=${PRODUCTS}/cmake/v2_8_4/source

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

mkdir -p ${cmakedir}/build
if [ ! -d ${cmakedir}/build ]
then
   echo "ERROR: failed to create ${cmakedir}/build"
   exit 1
fi

set -x

# unwind tar file
cd ${sourcedir}
tar xzf cmake-2.8.4.tar.gz
# apply Fermi patches
cd ${sourcedir}/cmake-2.8.4
patch -b -p0 < ${sourcedir}/cmake-2.8.4.libarchive.patch

cd ${cmakedir}/build

${cmakedir}/../source/cmake-2.8.4/bootstrap --prefix=${cmakedir} 
make 
make install 

set +x

if [ ! -d ${cmakedir}/bin ]
then
   echo "ERROR: failed to create ${cmakedir}/bin"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building cmake for flavor ${flvr}"
echo "Declaring cmake v2_8_4 for this flavor"
if [ ${OS} = "Darwin" ]
then
   ups declare cmake v2_8_4 -r cmake/v2_8_4 -2 -m cmake.table -c
else
   ups declare cmake v2_8_4 -r cmake/v2_8_4 -4 -m cmake.table -c
fi

setup cmake v2_8_4

exit 0
